artifician package
==================

.. automodule:: artifician
   :members:
   :undoc-members:
   :show-inheritance:


Subpackages
-----------

.. toctree::
   :maxdepth: 4

   artifician.processors

Submodules
----------

.. toctree::
   :maxdepth: 4

   artifician.dataset
   artifician.feature_definition
